@@ -10,7 +10,7 @@ def create_client_credentials():
     import boto3
 
     # Catch if running on Batch
-    if 'METAFLOW_INPUT_PATHS_0' in os.environ:
+    if ['METAFLOW_INPUT_PATHS_0', 'MANAGED_BY_AWS'] in os.environ:
         return boto3.session.Session(
             region_name='eu-west-1'
         )
